@@ -71,7 +71,7 @@ class AutoFeat(object):
             trans_primitives = [
                 "year", "month", "day", "hour", "minute", "week", "weekday", "is_weekend",
                 'time_since_previous',  # diff
-                Quarter(), WeekOfYear(),
+                Quarter(),
             ]
 
         _ = ft.dfs(
@@ -83,8 +83,8 @@ class AutoFeat(object):
             chunk_size=chunk_size,
             n_jobs=n_jobs,
             verbose=1,
-            trans_primitives=trans_primitives,
             agg_primitives=agg_primitives,
+            trans_primitives=trans_primitives,
             **kwargs
         )
 
